@@ -10,22 +10,17 @@ class RouteData(TypedDict):
 
     RouteID: str
     Name: str
-    LineDescription: list[str]
+    LineDescription: str
 
 
 @dataclass
 class Route:
     """A MetroBus Route."""
 
-    data: RouteData
+    data: RouteData = field(repr=False)
     route_id: str = field(init=False)
     name: str = field(init=False)
-    line_description: list[str] = field(init=False)
-
-    def __repr__(self) -> str:
-        """Return the representation."""
-        cls_name = type(self).__name__
-        return f"{cls_name}(id={self.route_id}, name={self.name})"
+    line_description: str = field(init=False)
 
     def __hash__(self) -> int:
         """Return the hash."""
