@@ -26,8 +26,8 @@ class StopTimeData(TypedDict):
 class StopTime:
     """Stop Time for a Route Schedule."""
 
-    bus: "MetroBus"
-    data: StopTimeData
+    direction_schedule: DirectionSchedule
+    data: StopTimeData = field(repr=False)
     stop_id: str = field(init=False)
     stop_name: str = field(init=False)
     stop_sequence: int = field(init=False)
@@ -40,10 +40,14 @@ class StopTime:
         self.stop_sequence = self.data["StopSeq"]
         self.time = datetime.fromisoformat(self.data["Time"]).replace(tzinfo=TZ)
 
+    def __hash__(self) -> int:
+        """Return the hash."""
+        return hash((self.stop, self.direction_schedule))
+
     @property
     def stop(self) -> Stop:
         """Get stop."""
-        return self.bus.stops[self.stop_id]
+        return self.direction_schedule.route_schedule.bus.stops[self.stop_id]
 
 
 class DirectionScheduleData(TypedDict):
@@ -63,14 +67,14 @@ class DirectionScheduleData(TypedDict):
 class DirectionSchedule:
     """Direction Schedule for a Path."""
 
-    bus: "MetroBus"
-    data: DirectionScheduleData
+    route_schedule: RouteSchedule
+    data: DirectionScheduleData = field(repr=False)
     direction_num: int
     end_time: datetime = field(init=False)
-    route_id: str = field(init=False)
+    route_id: str = field(init=False, repr=False)
     route: Route = field(init=False)
     start_time: datetime = field(init=False)
-    stop_times_data: list[StopTimeData] = field(init=False)
+    stop_times_data: list[StopTimeData] = field(init=False, repr=False)
     stop_times: list[StopTime] = field(init=False)
     trip_direction: str = field(init=False)
     trip_headsign: str = field(init=False)
@@ -80,22 +84,23 @@ class DirectionSchedule:
         """Post init."""
         self.end_time = datetime.fromisoformat(self.data["EndTime"]).replace(tzinfo=TZ)
         self.route_id = self.data["RouteID"]
-        self.route = self.bus.routes[self.route_id]
+        self.route = self.route_schedule.bus.routes[self.route_id]
         self.start_time = datetime.fromisoformat(self.data["StartTime"]).replace(
             tzinfo=TZ
         )
         self.stop_times_data = self.data["StopTimes"]
         self.stop_times = sorted(
-            [
-                StopTime(self.bus, stop_time_data)
-                for stop_time_data in self.stop_times_data
-            ],
+            [StopTime(self, stop_time_data) for stop_time_data in self.stop_times_data],
             key=lambda stop_time: stop_time.stop_sequence,
         )
         self.trip_direction = self.data["TripDirectionText"]
         self.trip_headsign = self.data["TripHeadsign"]
         self.trip_id = self.data["TripID"]
 
+    def __hash__(self) -> int:
+        """Return the hash."""
+        return hash((self.direction_num, self.route, self.trip_id))
+
 
 class RouteScheduleData(TypedDict):
     """Route schedule data for MetroBus WMATA API."""
@@ -108,9 +113,9 @@ class RouteScheduleData(TypedDict):
 class RouteSchedule:
     """Schedule for a Route."""
 
-    bus: "MetroBus"
+    bus: "MetroBus" = field(repr=False)
     route: "Route"
-    data: RouteScheduleData
+    data: RouteScheduleData = field(repr=False)
     directions_schedules: dict[int, list[DirectionSchedule]] = field(
         init=False, default_factory=dict
     )
@@ -120,7 +125,7 @@ class RouteSchedule:
         if (direction_schedules_data := self.data["Direction0"]) is not None:
             self.directions_schedules[0] = sorted(
                 [
-                    DirectionSchedule(self.bus, direction_schedule_data, 0)
+                    DirectionSchedule(self, direction_schedule_data, 0)
                     for direction_schedule_data in direction_schedules_data
                 ],
                 key=lambda direction_schedule: direction_schedule.start_time,
@@ -128,8 +133,12 @@ class RouteSchedule:
         if (direction_schedules_data := self.data["Direction1"]) is not None:
             self.directions_schedules[1] = sorted(
                 [
-                    DirectionSchedule(self.bus, direction_schedule_data, 1)
+                    DirectionSchedule(self, direction_schedule_data, 1)
                     for direction_schedule_data in direction_schedules_data
                 ],
                 key=lambda direction_schedule: direction_schedule.start_time,
             )
+
+    def __hash__(self) -> int:
+        """Return the hash."""
+        return hash(self.directions_schedules.values())
